@@ -31,12 +31,27 @@ except Exception:
 
 __author__ = "Claude MPM Team"
 
-# Import main components
-from .core.claude_runner import ClaudeRunner
-from .services.ticket_manager import TicketManager
 
-# For backwards compatibility
-MPMOrchestrator = ClaudeRunner
+# Lazy imports for main components to avoid loading heavy dependencies
+# when only importing from submodules (e.g., core.logging_utils)
+# This significantly improves hook handler performance
+def __getattr__(name):
+    """Lazy load main components only when accessed."""
+    if name == "ClaudeRunner":
+        from .core.claude_runner import ClaudeRunner
+
+        return ClaudeRunner
+    if name == "MPMOrchestrator":
+        # For backwards compatibility
+        from .core.claude_runner import ClaudeRunner
+
+        return ClaudeRunner
+    if name == "TicketManager":
+        from .services.ticket_manager import TicketManager
+
+        return TicketManager
+    raise AttributeError(f"module '{__name__}' has no attribute '{name}'")
+
 
 __all__ = [
     "ClaudeRunner",
