@@ -37,7 +37,7 @@ find_claude_mpm() {
             cmd_path=$(readlink -f "$cmd_path")
         fi
         # Extract the base directory (usually site-packages or venv)
-        local base_dir=$(python3 -c "import claude_mpm; import os; print(os.path.dirname(os.path.dirname(claude_mpm.__file__)))" 2>/dev/null)
+        local base_dir=$(python3 -c "import claude_mpm; import os; print(Path(os.path.dirname(claude_mpm.__file__).parent))" 2>/dev/null)
         if [ -n "$base_dir" ]; then
             echo "$base_dir"
             return 0
@@ -71,7 +71,7 @@ try:
     import claude_mpm
     import os
     # Get the package directory
-    pkg_dir = os.path.dirname(claude_mpm.__file__)
+    pkg_dir = Path(claude_mpm.__file__).parent
     # Check if we're in a development install (src directory)
     if 'src' in pkg_dir:
         # Go up to find the project root
@@ -81,11 +81,11 @@ try:
             project_root = os.sep.join(parts[:src_idx])
             print(project_root)
         else:
-            print(os.path.dirname(os.path.dirname(pkg_dir)))
+            print(Path(os.path.dirname(pkg_dir).parent))
     else:
         # Installed package - just return the package location
-        print(os.path.dirname(pkg_dir))
-except:
+        print(Path(pkg_dir).parent)
+except Exception:
     pass
 " 2>/dev/null)
 
@@ -99,7 +99,7 @@ except:
     for path_dir in $PATH; do
         if [ -f "$path_dir/claude-mpm" ]; then
             # Found claude-mpm executable, try to find its package
-            local pkg_dir=$(cd "$path_dir" && python3 -c "import claude_mpm; import os; print(os.path.dirname(os.path.dirname(claude_mpm.__file__)))" 2>/dev/null)
+            local pkg_dir=$(cd "$path_dir" && python3 -c "import claude_mpm; import os; print(Path(os.path.dirname(claude_mpm.__file__).parent))" 2>/dev/null)
             if [ -n "$pkg_dir" ]; then
                 echo "$pkg_dir"
                 return 0
@@ -339,8 +339,8 @@ main "$@"
 
         # Make sure it's executable
         if script_path.exists():
-            st = os.stat(script_path)
-            os.chmod(script_path, st.st_mode | stat.S_IEXEC)
+            st = Path(script_path).stat()
+            Path(script_path).chmod(st.st_mode | stat.S_IEXEC)
             self._hook_script_path = script_path
             return script_path
 
@@ -428,7 +428,7 @@ main "$@"
             return
 
         try:
-            with open(self.old_settings_file) as f:
+            with self.old_settings_file.open() as f:
                 old_settings = json.load(f)
 
             # Remove hooks section if present
@@ -437,7 +437,7 @@ main "$@"
                 self.logger.info(f"Removing hooks from {self.old_settings_file}")
 
                 # Write back the cleaned settings
-                with open(self.old_settings_file, "w") as f:
+                with self.old_settings_file.open("w") as f:
                     json.dump(old_settings, f, indent=2)
 
                 self.logger.info(f"Cleaned up hooks from {self.old_settings_file}")
@@ -450,7 +450,7 @@ main "$@"
 
         # Load existing settings.json or create new
         if self.settings_file.exists():
-            with open(self.settings_file) as f:
+            with self.settings_file.open() as f:
                 settings = json.load(f)
             self.logger.info(f"Found existing Claude settings at {self.settings_file}")
         else:
@@ -490,7 +490,7 @@ main "$@"
             ]
 
         # Write settings to settings.json
-        with open(self.settings_file, "w") as f:
+        with self.settings_file.open("w") as f:
             json.dump(settings, f, indent=2)
 
         self.logger.info(f"Updated Claude settings at {self.settings_file}")
@@ -500,9 +500,19 @@ main "$@"
 
     def _install_commands(self) -> None:
         """Install custom commands for Claude Code."""
-        # Find commands directory in the package
-        package_root = Path(__file__).parent.parent.parent.parent
-        commands_src = package_root / ".claude" / "commands"
+        # Find commands directory using proper resource resolution
+        try:
+            from ...core.unified_paths import get_package_resource_path
+
+            commands_src = get_package_resource_path("commands")
+        except FileNotFoundError:
+            # Fallback to hardcoded path exploration for development
+            package_root = Path(__file__).parent.parent.parent.parent
+            commands_src = package_root / ".claude" / "commands"
+
+            if not commands_src.exists():
+                # Try the actual location in src/claude_mpm/commands
+                commands_src = Path(__file__).parent.parent.parent / "commands"
 
         if not commands_src.exists():
             self.logger.debug(
@@ -554,7 +564,7 @@ main "$@"
             issues.append(f"Claude settings file not found at {self.settings_file}")
         else:
             try:
-                with open(self.settings_file) as f:
+                with self.settings_file.open() as f:
                     settings = json.load(f)
 
                 if "hooks" not in settings:
@@ -578,9 +588,9 @@ main "$@"
                 issues.append(f"Invalid Claude settings JSON: {e}")
 
         # Check if claude-mpm is accessible
-        try:
-            import claude_mpm
-        except ImportError:
+        import importlib.util
+
+        if importlib.util.find_spec("claude_mpm") is None:
             issues.append("claude-mpm package not found in Python environment")
 
         is_valid = len(issues) == 0
@@ -605,7 +615,7 @@ main "$@"
             # Remove from Claude settings (both old and new locations)
             for settings_path in [self.settings_file, self.old_settings_file]:
                 if settings_path.exists():
-                    with open(settings_path) as f:
+                    with settings_path.open() as f:
                         settings = json.load(f)
 
                     if "hooks" in settings:
@@ -645,7 +655,7 @@ main "$@"
                             del settings["hooks"]
 
                         # Write back settings
-                        with open(settings_path, "w") as f:
+                        with settings_path.open("w") as f:
                             json.dump(settings, f, indent=2)
 
                         self.logger.info(f"Removed hooks from {settings_path}")
@@ -699,18 +709,18 @@ main "$@"
 
         if self.settings_file.exists():
             try:
-                with open(self.settings_file) as f:
+                with self.settings_file.open() as f:
                     settings = json.load(f)
                     if "hooks" in settings:
                         status["configured_events"] = list(settings["hooks"].keys())
                         configured_in_local = True
-            except:
+            except Exception:
                 pass
 
         # Also check old settings file
         if self.old_settings_file.exists():
             try:
-                with open(self.old_settings_file) as f:
+                with self.old_settings_file.open() as f:
                     old_settings = json.load(f)
                     if "hooks" in old_settings:
                         status["old_file_has_hooks"] = True
@@ -718,7 +728,7 @@ main "$@"
                             status["warning"] = (
                                 "Hooks found in settings.local.json but Claude Code reads from settings.json"
                             )
-            except:
+            except Exception:
                 pass
 
         status["settings_location"] = (
