@@ -176,23 +176,47 @@ class MultiSourceAgentDeploymentService:
                 # Log if a higher priority source was overridden by version
                 for other_agent in agent_versions:
                     if other_agent != highest_version_agent:
-                        self.version_manager.parse_version(
+                        # Parse both versions for comparison
+                        other_version = self.version_manager.parse_version(
                             other_agent.get("version", "0.0.0")
                         )
-                        if (
-                            other_agent["source"] == "project"
-                            and highest_version_agent["source"] == "system"
+                        highest_version = self.version_manager.parse_version(
+                            highest_version_agent.get("version", "0.0.0")
+                        )
+
+                        # Compare the versions
+                        version_comparison = self.version_manager.compare_versions(
+                            other_version, highest_version
+                        )
+
+                        # Only warn if the other version is actually lower
+                        if version_comparison < 0:
+                            if (
+                                other_agent["source"] == "project"
+                                and highest_version_agent["source"] == "system"
+                            ):
+                                self.logger.warning(
+                                    f"Project agent '{agent_name}' v{other_agent['version']} "
+                                    f"overridden by higher system version v{highest_version_agent['version']}"
+                                )
+                            elif other_agent[
+                                "source"
+                            ] == "user" and highest_version_agent["source"] in [
+                                "system",
+                                "project",
+                            ]:
+                                self.logger.warning(
+                                    f"User agent '{agent_name}' v{other_agent['version']} "
+                                    f"overridden by higher {highest_version_agent['source']} version v{highest_version_agent['version']}"
+                                )
+                        elif (
+                            version_comparison == 0
+                            and other_agent["source"] != highest_version_agent["source"]
                         ):
-                            self.logger.warning(
-                                f"Project agent '{agent_name}' v{other_agent['version']} "
-                                f"overridden by higher system version v{highest_version_agent['version']}"
-                            )
-                        elif other_agent["source"] == "user" and highest_version_agent[
-                            "source"
-                        ] in ["system", "project"]:
-                            self.logger.warning(
-                                f"User agent '{agent_name}' v{other_agent['version']} "
-                                f"overridden by higher {highest_version_agent['source']} version v{highest_version_agent['version']}"
+                            # Log info when versions are equal but different sources
+                            self.logger.info(
+                                f"Using {highest_version_agent['source']} source for '{agent_name}' "
+                                f"(same version v{highest_version_agent['version']} as {other_agent['source']} source)"
                             )
 
         return selected_agents
@@ -469,6 +493,47 @@ class MultiSourceAgentDeploymentService:
 
         return cleanup_results
 
+    def _is_user_created_agent(self, agent_file: Path) -> bool:
+        """Check if an agent is user-created based on metadata.
+
+        User agents are identified by:
+        - Lack of MPM authorship indicators
+        - Missing version or v0.0.0
+        - Certain naming patterns
+
+        Args:
+            agent_file: Path to the agent file to check
+
+        Returns:
+            True if the agent appears to be user-created, False otherwise
+        """
+        try:
+            content = agent_file.read_text()
+
+            # Check for MPM authorship indicators
+            mpm_indicators = [
+                "author: claude-mpm",
+                "author: 'claude-mpm'",
+                'author: "claude-mpm"',
+                "author: Claude MPM",
+                "Claude MPM Team",
+                "Generated by Claude MPM",
+                "claude-mpm-project",
+            ]
+
+            for indicator in mpm_indicators:
+                if indicator.lower() in content.lower():
+                    return False  # This is an MPM agent
+
+            # Check for version 0.0.0 (typical user agent default)
+            if "version: 0.0.0" in content or "version: '0.0.0'" in content:
+                return True
+
+            return True  # Default to user-created if no MPM indicators
+
+        except Exception:
+            return True  # Default to user-created if we can't read it
+
     def _apply_config_filters(
         self, selected_agents: Dict[str, Dict[str, Any]], config: Config
     ) -> Dict[str, Dict[str, Any]]:
@@ -534,7 +599,8 @@ class MultiSourceAgentDeploymentService:
             "needs_update": [],
             "up_to_date": [],
             "new_agents": [],
-            "orphaned_agents": [],  # Agents without templates
+            "orphaned_agents": [],  # System agents without templates
+            "user_agents": [],  # User-created agents (no templates required)
             "version_upgrades": [],
             "version_downgrades": [],
             "source_changes": [],
@@ -655,10 +721,11 @@ class MultiSourceAgentDeploymentService:
                 )
 
         # Check for orphaned agents (deployed but no template)
-        orphaned = self._detect_orphaned_agents_simple(
+        system_orphaned, user_orphaned = self._detect_orphaned_agents_simple(
             deployed_agents_dir, agents_to_deploy
         )
-        comparison_results["orphaned_agents"] = orphaned
+        comparison_results["orphaned_agents"] = system_orphaned
+        comparison_results["user_agents"] = user_orphaned
 
         # Log summary
         summary_parts = [
@@ -668,23 +735,29 @@ class MultiSourceAgentDeploymentService:
         ]
         if comparison_results["orphaned_agents"]:
             summary_parts.append(
-                f"{len(comparison_results['orphaned_agents'])} orphaned"
+                f"{len(comparison_results['orphaned_agents'])} system orphaned"
+            )
+        if comparison_results["user_agents"]:
+            summary_parts.append(
+                f"{len(comparison_results['user_agents'])} user agents"
             )
 
         self.logger.info(f"Version comparison complete: {', '.join(summary_parts)}")
 
+        # Don't log upgrades here - let the caller decide when to log
+        # This prevents repeated upgrade messages on every startup
         if comparison_results["version_upgrades"]:
             for upgrade in comparison_results["version_upgrades"]:
-                self.logger.info(
-                    f"  Upgrade: {upgrade['name']} "
+                self.logger.debug(
+                    f"  Upgrade available: {upgrade['name']} "
                     f"{upgrade['deployed_version']} -> {upgrade['new_version']} "
                     f"(from {upgrade['source']})"
                 )
 
         if comparison_results["source_changes"]:
             for change in comparison_results["source_changes"]:
-                self.logger.info(
-                    f"  Source change: {change['name']} "
+                self.logger.debug(
+                    f"  Source change available: {change['name']} "
                     f"from {change['from_source']} to {change['to_source']}"
                 )
 
@@ -698,10 +771,10 @@ class MultiSourceAgentDeploymentService:
                     f"{downgrade['template_version']} (keeping deployed version)"
                 )
 
-        # Log orphaned agents if found
+        # Log system orphaned agents if found
         if comparison_results["orphaned_agents"]:
             self.logger.info(
-                f"Found {len(comparison_results['orphaned_agents'])} orphaned agent(s) "
+                f"Found {len(comparison_results['orphaned_agents'])} system orphaned agent(s) "
                 f"(deployed without templates):"
             )
             for orphan in comparison_results["orphaned_agents"]:
@@ -710,6 +783,18 @@ class MultiSourceAgentDeploymentService:
                     f"(consider removing or creating a template)"
                 )
 
+        # Log user agents at debug level if found
+        if comparison_results["user_agents"]:
+            self.logger.debug(
+                f"Found {len(comparison_results['user_agents'])} user-created agent(s) "
+                f"(no templates required):"
+            )
+            for user_agent in comparison_results["user_agents"]:
+                self.logger.debug(
+                    f"  - {user_agent['name']} v{user_agent['version']} "
+                    f"(user-created agent)"
+                )
+
         return comparison_results
 
     def _infer_agent_source_from_context(
@@ -767,11 +852,13 @@ class MultiSourceAgentDeploymentService:
                 ):
                     # In development mode, unknown agents are likely system agents being tested
                     return "system"
-                if deployment_context == DeploymentContext.PIPX_INSTALL:
-                    # In pipx mode, unknown agents could be system agents
-                    # Check if agent follows system naming patterns
-                    if agent_name.count("-") <= 2 and len(agent_name) <= 20:
-                        return "system"
+                if (
+                    deployment_context == DeploymentContext.PIPX_INSTALL
+                    and agent_name.count("-") <= 2
+                    and len(agent_name) <= 20
+                ):
+                    # In pipx mode, check if agent follows system naming patterns
+                    return "system"
             except Exception:
                 pass
 
@@ -860,7 +947,7 @@ class MultiSourceAgentDeploymentService:
 
     def _detect_orphaned_agents_simple(
         self, deployed_agents_dir: Path, agents_to_deploy: Dict[str, Path]
-    ) -> List[Dict[str, Any]]:
+    ) -> Tuple[List[Dict[str, Any]], List[Dict[str, Any]]]:
         """Simple orphan detection that works with agents_to_deploy structure.
 
         Args:
@@ -868,12 +955,13 @@ class MultiSourceAgentDeploymentService:
             agents_to_deploy: Dictionary mapping file stems to template paths
 
         Returns:
-            List of orphaned agent information
+            Tuple of (system_orphaned_agents, user_orphaned_agents)
         """
-        orphaned = []
+        system_orphaned = []
+        user_orphaned = []
 
         if not deployed_agents_dir.exists():
-            return orphaned
+            return system_orphaned, user_orphaned
 
         # agents_to_deploy already contains file stems as keys
         available_stems = set(agents_to_deploy.keys())
@@ -885,7 +973,7 @@ class MultiSourceAgentDeploymentService:
             if agent_stem in available_stems:
                 continue
 
-            # This is an orphaned agent
+            # This is an orphaned agent - determine if it's user-created or system
             try:
                 deployed_content = deployed_file.read_text()
                 deployed_version, _, _ = (
@@ -899,11 +987,19 @@ class MultiSourceAgentDeploymentService:
             except Exception:
                 version_str = "unknown"
 
-            orphaned.append(
-                {"name": agent_stem, "file": str(deployed_file), "version": version_str}
-            )
+            orphan_info = {
+                "name": agent_stem,
+                "file": str(deployed_file),
+                "version": version_str,
+            }
 
-        return orphaned
+            # Determine if this is a user-created agent
+            if self._is_user_created_agent(deployed_file):
+                user_orphaned.append(orphan_info)
+            else:
+                system_orphaned.append(orphan_info)
+
+        return system_orphaned, user_orphaned
 
     def cleanup_orphaned_agents(
         self, deployed_agents_dir: Path, dry_run: bool = True
