@@ -5,14 +5,16 @@ including template validation, agent file validation, and
 deployment environment validation.
 """
 
+from claude_mpm.core.enums import ValidationSeverity
+
 from .agent_validator import AgentValidator
 from .deployment_validator import DeploymentValidator
 from .template_validator import TemplateValidator
-from .validation_result import ValidationResult, ValidationSeverity
+from .validation_result import ValidationResult
 
 __all__ = [
-    "DeploymentValidator",
     "AgentValidator",
+    "DeploymentValidator",
     "TemplateValidator",
     "ValidationResult",
     "ValidationSeverity",
