@@ -10,6 +10,8 @@ Now with optional async logging support for improved performance.
 Configuration via .claude-mpm/configuration.yaml.
 """
 
+# Try to import async logger for performance optimization
+import importlib.util
 import json
 import os
 from datetime import datetime, timezone
@@ -22,16 +24,11 @@ from claude_mpm.core.config import Config
 # Import centralized session manager
 from claude_mpm.services.session_manager import get_session_manager
 
-# Try to import async logger for performance optimization
-try:
-    from claude_mpm.services.async_session_logger import (
-        AsyncSessionLogger,
-        get_async_logger,
-        log_response_async,
-    )
+if importlib.util.find_spec("claude_mpm.services.async_session_logger"):
+    from claude_mpm.services.async_session_logger import get_async_logger
 
     ASYNC_AVAILABLE = True
-except ImportError:
+else:
     ASYNC_AVAILABLE = False
 
 from claude_mpm.core.logging_utils import get_logger
@@ -88,7 +85,7 @@ class ClaudeSessionLogger:
             # Use centralized SessionManager for session ID
             session_manager = get_session_manager()
             self.session_id = session_manager.get_session_id()
-            logger.info(
+            logger.debug(
                 f"ClaudeSessionLogger using session ID from SessionManager: {self.session_id}"
             )
 
@@ -125,11 +122,11 @@ class ClaudeSessionLogger:
                 # Synchronize session IDs - use the one we already generated
                 if self.session_id and hasattr(self._async_logger, "set_session_id"):
                     self._async_logger.set_session_id(self.session_id)
-                    logger.info(
+                    logger.debug(
                         f"Using async logger with session ID: {self.session_id}"
                     )
                 else:
-                    logger.info("Using async logger for improved performance")
+                    logger.debug("Using async logger for improved performance")
             except Exception as e:
                 logger.warning(
                     f"Failed to initialize async logger, falling back to sync: {e}"
@@ -224,7 +221,7 @@ class ClaudeSessionLogger:
 
         # Save response
         try:
-            with open(file_path, "w", encoding="utf-8") as f:
+            with file_path.open("w", encoding="utf-8") as f:
                 json.dump(response_data, f, indent=2, ensure_ascii=False)
 
             logger.debug(f"Logged response to {filename} for session {self.session_id}")
