@@ -9,7 +9,9 @@ import json
 import subprocess
 from pathlib import Path
 
-from ..models import DiagnosticResult, DiagnosticStatus
+from claude_mpm.core.enums import OperationResult, ServiceState, ValidationSeverity
+
+from ..models import DiagnosticResult
 from .base_check import BaseDiagnosticCheck
 
 
@@ -34,13 +36,13 @@ class MCPCheck(BaseDiagnosticCheck):
             # Check if MCP is installed
             install_result = self._check_installation()
             sub_results.append(install_result)
-            details["installed"] = install_result.status == DiagnosticStatus.OK
+            details["installed"] = install_result.status == OperationResult.SUCCESS
 
-            if install_result.status == DiagnosticStatus.OK:
+            if install_result.status == OperationResult.SUCCESS:
                 # Check MCP configuration
                 config_result = self._check_configuration()
                 sub_results.append(config_result)
-                details["configured"] = config_result.status == DiagnosticStatus.OK
+                details["configured"] = config_result.status == OperationResult.SUCCESS
 
                 # Check MCP server status
                 status_result = self._check_server_status()
@@ -52,17 +54,17 @@ class MCPCheck(BaseDiagnosticCheck):
                 sub_results.append(startup_result)
 
             # Determine overall status
-            if any(r.status == DiagnosticStatus.ERROR for r in sub_results):
-                status = DiagnosticStatus.ERROR
+            if any(r.status == ValidationSeverity.ERROR for r in sub_results):
+                status = ValidationSeverity.ERROR
                 message = "MCP server has critical issues"
             elif not details.get("installed", False):
-                status = DiagnosticStatus.WARNING
+                status = ValidationSeverity.WARNING
                 message = "MCP server not installed"
-            elif any(r.status == DiagnosticStatus.WARNING for r in sub_results):
-                status = DiagnosticStatus.WARNING
+            elif any(r.status == ValidationSeverity.WARNING for r in sub_results):
+                status = ValidationSeverity.WARNING
                 message = "MCP server needs configuration"
             else:
-                status = DiagnosticStatus.OK
+                status = OperationResult.SUCCESS
                 message = "MCP server properly configured"
 
             return DiagnosticResult(
@@ -76,7 +78,7 @@ class MCPCheck(BaseDiagnosticCheck):
         except Exception as e:
             return DiagnosticResult(
                 category=self.category,
-                status=DiagnosticStatus.ERROR,
+                status=ValidationSeverity.ERROR,
                 message=f"MCP check failed: {e!s}",
                 details={"error": str(e)},
             )
@@ -94,7 +96,7 @@ class MCPCheck(BaseDiagnosticCheck):
             if mcp_path.exists():
                 return DiagnosticResult(
                     category="MCP Installation",
-                    status=DiagnosticStatus.OK,
+                    status=OperationResult.SUCCESS,
                     message="MCP server installed",
                     details={"path": str(mcp_path), "installed": True},
                 )
@@ -112,7 +114,7 @@ class MCPCheck(BaseDiagnosticCheck):
                 path = result.stdout.strip()
                 return DiagnosticResult(
                     category="MCP Installation",
-                    status=DiagnosticStatus.OK,
+                    status=OperationResult.SUCCESS,
                     message="MCP server installed",
                     details={"path": path, "installed": True},
                 )
@@ -121,7 +123,7 @@ class MCPCheck(BaseDiagnosticCheck):
 
         return DiagnosticResult(
             category="MCP Installation",
-            status=DiagnosticStatus.WARNING,
+            status=ValidationSeverity.WARNING,
             message="MCP server not installed",
             details={"installed": False},
             fix_command="claude-mpm mcp install",
@@ -146,7 +148,7 @@ class MCPCheck(BaseDiagnosticCheck):
         if not config_path:
             return DiagnosticResult(
                 category="MCP Configuration",
-                status=DiagnosticStatus.WARNING,
+                status=ValidationSeverity.WARNING,
                 message="Claude Code config not found",
                 details={"configured": False},
                 fix_command="claude-mpm mcp config",
@@ -163,7 +165,7 @@ class MCPCheck(BaseDiagnosticCheck):
                 if not gateway:
                     return DiagnosticResult(
                         category="MCP Configuration",
-                        status=DiagnosticStatus.WARNING,
+                        status=ValidationSeverity.WARNING,
                         message="MCP gateway not configured",
                         details={"configured": False, "config_path": str(config_path)},
                         fix_command="claude-mpm mcp config",
@@ -175,7 +177,7 @@ class MCPCheck(BaseDiagnosticCheck):
                 if not command:
                     return DiagnosticResult(
                         category="MCP Configuration",
-                        status=DiagnosticStatus.ERROR,
+                        status=ValidationSeverity.ERROR,
                         message="MCP gateway misconfigured (no command)",
                         details={
                             "configured": True,
@@ -188,7 +190,7 @@ class MCPCheck(BaseDiagnosticCheck):
 
                 return DiagnosticResult(
                     category="MCP Configuration",
-                    status=DiagnosticStatus.OK,
+                    status=OperationResult.SUCCESS,
                     message="MCP gateway configured",
                     details={
                         "configured": True,
@@ -200,7 +202,7 @@ class MCPCheck(BaseDiagnosticCheck):
         except json.JSONDecodeError as e:
             return DiagnosticResult(
                 category="MCP Configuration",
-                status=DiagnosticStatus.ERROR,
+                status=ValidationSeverity.ERROR,
                 message="Invalid JSON in config file",
                 details={"error": str(e), "config_path": str(config_path)},
                 fix_description="Fix JSON syntax in Claude Code config",
@@ -208,7 +210,7 @@ class MCPCheck(BaseDiagnosticCheck):
         except Exception as e:
             return DiagnosticResult(
                 category="MCP Configuration",
-                status=DiagnosticStatus.WARNING,
+                status=ValidationSeverity.WARNING,
                 message=f"Could not check configuration: {e!s}",
                 details={"error": str(e)},
             )
@@ -226,41 +228,53 @@ class MCPCheck(BaseDiagnosticCheck):
             )
 
             if result.returncode == 0:
-                if "running" in result.stdout.lower():
+                if ServiceState.RUNNING.value in result.stdout.lower():
                     return DiagnosticResult(
                         category="MCP Server Status",
-                        status=DiagnosticStatus.OK,
+                        status=OperationResult.SUCCESS,
                         message="MCP server is running",
-                        details={"running": True},
+                        details={"running": True, "state": ServiceState.RUNNING},
                     )
                 return DiagnosticResult(
                     category="MCP Server Status",
-                    status=DiagnosticStatus.WARNING,
+                    status=ValidationSeverity.WARNING,
                     message="MCP server not running",
-                    details={"running": False},
+                    details={"running": False, "state": ServiceState.STOPPED},
                     fix_command="claude-mpm mcp start",
                     fix_description="Start the MCP server",
                 )
             return DiagnosticResult(
                 category="MCP Server Status",
-                status=DiagnosticStatus.WARNING,
+                status=ValidationSeverity.WARNING,
                 message="Could not determine server status",
-                details={"running": "unknown", "error": result.stderr},
+                details={
+                    "running": "unknown",
+                    "state": ServiceState.UNKNOWN,
+                    "error": result.stderr,
+                },
             )
 
         except subprocess.TimeoutExpired:
             return DiagnosticResult(
                 category="MCP Server Status",
-                status=DiagnosticStatus.WARNING,
+                status=ValidationSeverity.WARNING,
                 message="Server status check timed out",
-                details={"running": "unknown", "error": "timeout"},
+                details={
+                    "running": "unknown",
+                    "state": ServiceState.UNKNOWN,
+                    "error": "timeout",
+                },
             )
         except Exception as e:
             return DiagnosticResult(
                 category="MCP Server Status",
-                status=DiagnosticStatus.WARNING,
+                status=ValidationSeverity.WARNING,
                 message=f"Could not check server status: {e!s}",
-                details={"running": "unknown", "error": str(e)},
+                details={
+                    "running": "unknown",
+                    "state": ServiceState.UNKNOWN,
+                    "error": str(e),
+                },
             )
 
     def _check_startup_verification(self) -> DiagnosticResult:
@@ -276,7 +290,7 @@ class MCPCheck(BaseDiagnosticCheck):
             if not issues:
                 return DiagnosticResult(
                     category="MCP Startup Verification",
-                    status=DiagnosticStatus.OK,
+                    status=OperationResult.SUCCESS,
                     message="Startup verification passed",
                     details={"issues": []},
                 )
@@ -290,20 +304,20 @@ class MCPCheck(BaseDiagnosticCheck):
             if errors:
                 return DiagnosticResult(
                     category="MCP Startup Verification",
-                    status=DiagnosticStatus.ERROR,
+                    status=ValidationSeverity.ERROR,
                     message=f"{len(errors)} critical issue(s) found",
                     details={"errors": errors, "warnings": warnings},
                 )
             if warnings:
                 return DiagnosticResult(
                     category="MCP Startup Verification",
-                    status=DiagnosticStatus.WARNING,
+                    status=ValidationSeverity.WARNING,
                     message=f"{len(warnings)} warning(s) found",
                     details={"warnings": warnings},
                 )
             return DiagnosticResult(
                 category="MCP Startup Verification",
-                status=DiagnosticStatus.OK,
+                status=OperationResult.SUCCESS,
                 message="Startup verification passed",
                 details={"issues": []},
             )
@@ -311,7 +325,7 @@ class MCPCheck(BaseDiagnosticCheck):
         except Exception as e:
             return DiagnosticResult(
                 category="MCP Startup Verification",
-                status=DiagnosticStatus.WARNING,
+                status=ValidationSeverity.WARNING,
                 message=f"Could not verify startup: {e!s}",
                 details={"error": str(e)},
             )
