@@ -22,7 +22,6 @@ documentation verbatim. Creates concise learnings that fit memory constraints
 while preserving essential information.
 """
 
-import os
 import re
 from datetime import datetime, timezone
 from pathlib import Path
@@ -118,7 +117,7 @@ class MemoryBuilder(LoggerMixin):
             self.config = config_loader.load_main_config()
         self.project_root = get_path_manager().project_root
         # Use current working directory by default, not project root
-        self.working_directory = working_directory or Path(os.getcwd())
+        self.working_directory = working_directory or Path(Path.cwd())
         self.memories_dir = self.working_directory / ".claude-mpm" / "memories"
         self.router = MemoryRouter(config)
         self.project_analyzer = ProjectAnalyzer(config, self.working_directory)
@@ -458,7 +457,7 @@ class MemoryBuilder(LoggerMixin):
                         import tomllib
                     except ImportError:
                         import tomli as tomllib
-                    with open(file_path, "rb") as f:
+                    with file_path.open("rb") as f:
                         config_data = tomllib.load(f)
                     items = self._extract_from_toml_config(config_data, source)
                     extracted_items.extend(items)
