@@ -25,6 +25,7 @@ Features:
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Union
 
+from claude_mpm.core.enums import OperationResult, ServiceState, ValidationSeverity
 from claude_mpm.core.logging_utils import get_logger
 
 from .interfaces import (
@@ -134,7 +135,7 @@ class UnifiedAnalyzer(IAnalyzerService, IUnifiedService):
 
         return {
             "service": "UnifiedAnalyzer",
-            "status": "healthy" if self._initialized else "unhealthy",
+            "status": ServiceState.RUNNING if self._initialized else ServiceState.ERROR,
             "initialized": self._initialized,
             "registered_strategies": len(strategies),
             "cache_size": len(self._analysis_cache),
@@ -223,7 +224,7 @@ class UnifiedAnalyzer(IAnalyzerService, IUnifiedService):
                 return AnalysisResult(
                     success=False,
                     summary=f"No strategy available for analysis type: {analysis_type}",
-                    severity="error",
+                    severity=ValidationSeverity.ERROR,
                 )
 
             # Execute analysis using strategy
@@ -236,7 +237,7 @@ class UnifiedAnalyzer(IAnalyzerService, IUnifiedService):
                 return AnalysisResult(
                     success=False,
                     summary=f"Validation failed: {'; '.join(validation_errors)}",
-                    severity="error",
+                    severity=ValidationSeverity.ERROR,
                 )
 
             # Perform analysis
@@ -251,7 +252,7 @@ class UnifiedAnalyzer(IAnalyzerService, IUnifiedService):
                 findings=result_data.get("findings", []),
                 metrics=metrics,
                 summary=result_data.get("summary", "Analysis completed"),
-                severity=result_data.get("severity", "info"),
+                severity=result_data.get("severity", ValidationSeverity.INFO),
                 recommendations=result_data.get("recommendations", []),
             )
 
@@ -343,8 +344,8 @@ class UnifiedAnalyzer(IAnalyzerService, IUnifiedService):
 
             if not result1.success or not result2.success:
                 return {
-                    "success": False,
-                    "error": "Failed to analyze one or both targets",
+                    OperationResult.SUCCESS.value: False,
+                    OperationResult.ERROR.value: "Failed to analyze one or both targets",
                 }
 
             # Compare metrics
@@ -354,7 +355,7 @@ class UnifiedAnalyzer(IAnalyzerService, IUnifiedService):
             finding_diff = self._compare_findings(result1.findings, result2.findings)
 
             return {
-                "success": True,
+                OperationResult.SUCCESS.value: True,
                 "target1": str(target1),
                 "target2": str(target2),
                 "metric_differences": metric_diff,
@@ -378,7 +379,10 @@ class UnifiedAnalyzer(IAnalyzerService, IUnifiedService):
 
         except Exception as e:
             self._logger.error(f"Comparison error: {e!s}")
-            return {"success": False, "error": str(e)}
+            return {
+                OperationResult.SUCCESS.value: False,
+                OperationResult.ERROR.value: str(e),
+            }
 
     def get_recommendations(
         self, analysis_result: AnalysisResult
@@ -405,7 +409,7 @@ class UnifiedAnalyzer(IAnalyzerService, IUnifiedService):
             )
 
         # Add severity-based recommendations
-        if analysis_result.severity == "critical":
+        if analysis_result.severity == ValidationSeverity.CRITICAL:
             recommendations.insert(
                 0,
                 {
@@ -414,7 +418,7 @@ class UnifiedAnalyzer(IAnalyzerService, IUnifiedService):
                     "priority": "high",
                 },
             )
-        elif analysis_result.severity == "error":
+        elif analysis_result.severity == ValidationSeverity.ERROR:
             recommendations.insert(
                 0,
                 {
