@@ -113,7 +113,7 @@ class EnhancedVersionParser:
             r"(\d+)\.(\d+)\.(\d+)(?:-([a-zA-Z0-9\-\.]+))?(?:\+([a-zA-Z0-9\-\.]+))?"
         )
         self._changelog_version_pattern = re.compile(
-            r"##\s*\[?([0-9]+\.[0-9]+\.[0-9]+[^\]]*)\]?\s*[-–]\s*(\d{4}-\d{2}-\d{2})?"
+            r"##\s*\[?([0-9]+\.[0-9]+\.[0-9]+[^\]]*)\]?\s*[--]\s*(\d{4}-\d{2}-\d{2})?"
         )
 
     def _get_cached(self, key: str) -> Optional[any]:
@@ -365,7 +365,7 @@ class EnhancedVersionParser:
         package_file = self.project_root / "package.json"
         if package_file.exists():
             try:
-                with open(package_file) as f:
+                with package_file.open() as f:
                     data = json.load(f)
                     version = data.get("version")
                     if version and self._version_pattern.match(version):
